window.Gleam.initSearch([{"doc":"gsmtp","title":"gsmtp","content":"# gsmtp\n\nSMTP Client for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/gsmtp)](https://hex.pm/packages/gsmtp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gsmtp/)\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gsmtp&gt;.\n\n## Current state\n\nA simple mail to a SMTP server can be sent\n\nUse it like this\n\n```sh\ngleam add gsmtp\n```\n\n```gleam\nimport gsmtp/builder\nimport gsmtp/smtp\nimport logging\n\npub fn main() {\n  logging.configure()\n  logging.set_level(logging.Debug)\n\n  let message =\n    builder.new_builder()\n    |&gt; builder.from_email(&quot;test@example.com&quot;)\n    |&gt; builder.to_emails([&quot;user@localhost&quot;])\n    |&gt; builder.subject(&quot;SMTP Mail from gleam&quot;)\n    |&gt; builder.body(&quot;This is a test mail from gleam&quot;)\n    |&gt; builder.create()\n\n  let assert Ok(Nil) = smtp.send(&quot;127.0.0.1&quot;, 25, message)\n}\n```\n\n## TODO\n\n- [ ] TLS\n- [ ] Auth\n- [ ] Extensions\n- [ ] Tests\n- [ ] Error handling\n- [ ] Docs\n- [ ] Cleanup API\n\n\n## Development\n\nSetup postfix (ubuntu) for a local SMTP server\n\n```sh\nsudo apt install postfix\n```\n\nMake sure to setup postfix to send mails only locally\n\nFor just simple SMTP command tests you can use telnet\n\n```sh\ntelnet localhost 25\n```\n\nand run the following commands\n\n```sh\nHELO localhost\nMAIL FROM:&lt;sender@example.com&gt;\nRCPT TO:&lt;user@localhost&gt;\nDATA\nSubject: Test Email\nFrom: sender@example.com\nTo: user@localhost\n\nThis is a test email sent manually.\n\n.\nQUIT\n```\n\nThis is basically what the library does. it opens a TCP connection and runs the commands\n\nRun the following command to see the mails:\n\n```sh\ntail -f /var/mail/user\n```\n\nTo test the gleam smtp client run\n\n```sh\ngleam test\n```\n\nThis project is inspired by the go [smtp](https://pkg.go.dev/net/smtp) package\n\nThats why there is a working smtp client in the `go/` directory.\n\nRun it with\n\n```sh\ngo run go/main.go\n```\n\n","url":"index.html"},{"doc":"builder","title":"Message","content":"pub type Message {\n  Message(\n    from: String,\n    to: List(String),\n    subject: String,\n    body: String,\n  )\n}\n\nMessage(\n  from: String,\n  to: List(String),\n  subject: String,\n  body: String,\n)\n\n\nSynonyms:\nbuilder.Message\nbuilder Message","url":"builder.html#Message"},{"doc":"builder","title":"MessageBuilder","content":"pub type MessageBuilder {\n  MessageBuilder(\n    from: Option(String),\n    to: Option(List(String)),\n    subject: Option(String),\n    body: Option(String),\n  )\n}\n\nMessageBuilder(\n  from: Option(String),\n  to: Option(List(String)),\n  subject: Option(String),\n  body: Option(String),\n)\n\n\nSynonyms:\nbuilder.MessageBuilder\nbuilder MessageBuilder","url":"builder.html#MessageBuilder"},{"doc":"builder","title":"body","content":"pub fn body(\n  message: MessageBuilder,\n  body: String,\n) -&gt; MessageBuilder\n\nSynonyms:\nbuilder.body\nbuilder body","url":"builder.html#body"},{"doc":"builder","title":"create","content":"pub fn create(message_builder: MessageBuilder) -&gt; Message\n\nSynonyms:\nbuilder.create\nbuilder create","url":"builder.html#create"},{"doc":"builder","title":"from_email","content":"pub fn from_email(\n  message: MessageBuilder,\n  from: String,\n) -&gt; MessageBuilder\n\nSynonyms:\nbuilder.from_email\nbuilder from_email","url":"builder.html#from_email"},{"doc":"builder","title":"new_builder","content":"pub fn new_builder() -&gt; MessageBuilder\n\nSynonyms:\nbuilder.new_builder\nbuilder new_builder","url":"builder.html#new_builder"},{"doc":"builder","title":"subject","content":"pub fn subject(\n  message: MessageBuilder,\n  subject: String,\n) -&gt; MessageBuilder\n\nSynonyms:\nbuilder.subject\nbuilder subject","url":"builder.html#subject"},{"doc":"builder","title":"to_emails","content":"pub fn to_emails(\n  message: MessageBuilder,\n  to: List(String),\n) -&gt; MessageBuilder\n\nSynonyms:\nbuilder.to_emails\nbuilder to_emails","url":"builder.html#to_emails"},{"doc":"builder","title":"builder","content":"","url":"builder.html"},{"doc":"smtp","title":"Error","content":"pub type Error {\n  TcpError(mug.Error)\n  MissingServerCodeError\n  InvalidServerCodeError(code: String, expected: Int)\n}\n\nTcpError(mug.Error)\n\n\nMissingServerCodeError\n\n\nInvalidServerCodeError(code: String, expected: Int)\n\n\nSynonyms:\nsmtp.Error\nsmtp Error","url":"smtp.html#Error"},{"doc":"smtp","title":"send","content":"pub fn send(\n  host: String,\n  port: Int,\n  message: Message,\n) -&gt; Result(Nil, Error)\n\nSynonyms:\nsmtp.send\nsmtp send","url":"smtp.html#send"},{"doc":"smtp","title":"smtp","content":"","url":"smtp.html"},{"doc":"gsmtp","title":"main","content":"pub fn main() -&gt; Result(Nil, Error)\n\nSynonyms:\ngsmtp.main\ngsmtp main","url":"gsmtp.html#main"},{"doc":"gsmtp","title":"gsmtp","content":"","url":"gsmtp.html"}]);